from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHLivePhoto(TestCase):
    def test_constants(self):
        self.assertEqual(Photos.PHLivePhotoRequestIDInvalid, 0)

    @min_os_level("10.15")
    def test_constants10_15(self):
        self.assertIsInstance(Photos.PHLivePhotoInfoErrorKey, str)
        self.assertIsInstance(Photos.PHLivePhotoInfoIsDegradedKey, str)
        self.assertIsInstance(Photos.PHLivePhotoInfoCancelledKey, str)

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            Photos.PHLivePhoto.requestLivePhotoWithResourceFileURLs_placeholderImage_targetSize_contentMode_resultHandler_,
            4,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHChange(TestCase):
    @min_os_level("10.13")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHObjectChangeDetails.assetContentChanged)
        self.assertResultIsBOOL(Photos.PHObjectChangeDetails.objectWasDeleted)

        self.assertResultIsBOOL(Photos.PHFetchResultChangeDetails.hasIncrementalChanges)
        self.assertResultIsBOOL(Photos.PHFetchResultChangeDetails.hasMoves)



from PyObjCTools.TestSupport import TestCase, min_os_level, max_os_level
import Photos


class TestPHAsset(TestCase):
    @min_os_level("10.13")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHAsset.isHidden)
        self.assertResultIsBOOL(Photos.PHAsset.isFavorite)

    @min_os_level("10.13")
    @max_os_level("10.14")
    def testMethods10_13_removed_in_10_15(self):
        self.assertResultIsBOOL(Photos.PHAsset.isSyncFailureHidden)

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(Photos.PHAsset.representsBurst)
        self.assertResultIsBOOL(Photos.PHAsset.canPerformEditOperation_)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHCloudIdentifier(TestCase):
    @min_os_level("10.13")
    def testConstants(self):
        self.assertIsInstance(Photos.PHLocalIdentifierNotFound, str)



import sys
from PyObjCTools.TestSupport import TestCase
import Photos


class TestPhotosTypes(TestCase):
    def test_constants(self):

        self.assertEqual(Photos.PHAssetMediaTypeUnknown, 0)
        self.assertEqual(Photos.PHAssetMediaTypeImage, 1)
        self.assertEqual(Photos.PHAssetMediaTypeVideo, 2)
        self.assertEqual(Photos.PHAssetMediaTypeAudio, 3)

        self.assertEqual(Photos.PHAssetMediaSubtypeNone, 0)

        self.assertEqual(Photos.PHAssetMediaSubtypePhotoPanorama, (1 << 0))
        self.assertEqual(Photos.PHAssetMediaSubtypePhotoHDR, (1 << 1))
        self.assertEqual(Photos.PHAssetMediaSubtypePhotoScreenshot, (1 << 2))
        self.assertEqual(Photos.PHAssetMediaSubtypePhotoLive, (1 << 3))
        self.assertEqual(Photos.PHAssetMediaSubtypePhotoDepthEffect, (1 << 4))

        self.assertEqual(Photos.PHAssetMediaSubtypeVideoStreamed, (1 << 16))
        self.assertEqual(Photos.PHAssetMediaSubtypeVideoHighFrameRate, (1 << 17))
        self.assertEqual(Photos.PHAssetMediaSubtypeVideoTimelapse, (1 << 18))

        self.assertEqual(Photos.PHImageContentModeAspectFit, 0)
        self.assertEqual(Photos.PHImageContentModeAspectFill, 1)
        self.assertEqual(Photos.PHImageContentModeDefault, 0)

        self.assertEqual(Photos.PHCollectionListTypeMomentList, 1)
        self.assertEqual(Photos.PHCollectionListTypeFolder, 2)
        self.assertEqual(Photos.PHCollectionListTypeSmartFolder, 3)

        self.assertEqual(Photos.PHCollectionListSubtypeMomentListCluster, 1)
        self.assertEqual(Photos.PHCollectionListSubtypeMomentListYear, 2)
        self.assertEqual(Photos.PHCollectionListSubtypeRegularFolder, 100)
        self.assertEqual(Photos.PHCollectionListSubtypeSmartFolderEvents, 200)
        self.assertEqual(Photos.PHCollectionListSubtypeSmartFolderFaces, 201)

        self.assertEqual(Photos.PHCollectionEditOperationDeleteContent, 1)
        self.assertEqual(Photos.PHCollectionEditOperationRemoveContent, 2)
        self.assertEqual(Photos.PHCollectionEditOperationAddContent, 3)
        self.assertEqual(Photos.PHCollectionEditOperationCreateContent, 4)
        self.assertEqual(Photos.PHCollectionEditOperationRearrangeContent, 5)
        self.assertEqual(Photos.PHCollectionEditOperationDelete, 6)
        self.assertEqual(Photos.PHCollectionEditOperationRename, 7)

        self.assertEqual(Photos.PHAssetCollectionTypeAlbum, 1)
        self.assertEqual(Photos.PHAssetCollectionTypeSmartAlbum, 2)
        self.assertEqual(Photos.PHAssetCollectionTypeMoment, 3)

        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumRegular, 2)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumSyncedEvent, 3)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumSyncedFaces, 4)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumSyncedAlbum, 5)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumImported, 6)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumMyPhotoStream, 100)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAlbumCloudShared, 101)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumGeneric, 200)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumPanoramas, 201)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumVideos, 202)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumFavorites, 203)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumTimelapses, 204)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumAllHidden, 205)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumRecentlyAdded, 206)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumBursts, 207)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumSlomoVideos, 208)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumUserLibrary, 209)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumSelfPortraits, 210)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumScreenshots, 211)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumDepthEffect, 212)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumLivePhotos, 213)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumAnimated, 214)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumLongExposures, 215)
        self.assertEqual(Photos.PHAssetCollectionSubtypeSmartAlbumUnableToUpload, 216)
        self.assertEqual(Photos.PHAssetCollectionSubtypeAny, sys.maxsize)

        self.assertEqual(Photos.PHAssetEditOperationDelete, 1)
        self.assertEqual(Photos.PHAssetEditOperationContent, 2)
        self.assertEqual(Photos.PHAssetEditOperationProperties, 3)

        self.assertEqual(Photos.PHAssetBurstSelectionTypeNone, 0)
        self.assertEqual(Photos.PHAssetBurstSelectionTypeAutoPick, 1 << 0)
        self.assertEqual(Photos.PHAssetBurstSelectionTypeUserPick, 1 << 1)

        self.assertEqual(Photos.PHAssetSourceTypeNone, 0)
        self.assertEqual(Photos.PHAssetSourceTypeUserLibrary, 1 << 0)
        self.assertEqual(Photos.PHAssetSourceTypeCloudShared, 1 << 1)
        self.assertEqual(Photos.PHAssetSourceTypeiTunesSynced, 1 << 2)

        self.assertEqual(Photos.PHAssetResourceTypePhoto, 1)
        self.assertEqual(Photos.PHAssetResourceTypeVideo, 2)
        self.assertEqual(Photos.PHAssetResourceTypeAudio, 3)
        self.assertEqual(Photos.PHAssetResourceTypeAlternatePhoto, 4)
        self.assertEqual(Photos.PHAssetResourceTypeFullSizePhoto, 5)
        self.assertEqual(Photos.PHAssetResourceTypeFullSizeVideo, 6)
        self.assertEqual(Photos.PHAssetResourceTypeAdjustmentData, 7)
        self.assertEqual(Photos.PHAssetResourceTypeAdjustmentBasePhoto, 8)
        self.assertEqual(Photos.PHAssetResourceTypePairedVideo, 9)
        self.assertEqual(Photos.PHAssetResourceTypeFullSizePairedVideo, 10)
        self.assertEqual(Photos.PHAssetResourceTypeAdjustmentBasePairedVideo, 11)
        self.assertEqual(Photos.PHAssetResourceTypeAdjustmentBaseVideo, 12)

        self.assertEqual(Photos.PHAssetPlaybackStyleUnsupported, 0)
        self.assertEqual(Photos.PHAssetPlaybackStyleImage, 1)
        self.assertEqual(Photos.PHAssetPlaybackStyleImageAnimated, 2)
        self.assertEqual(Photos.PHAssetPlaybackStyleLivePhoto, 3)
        self.assertEqual(Photos.PHAssetPlaybackStyleVideo, 4)
        self.assertEqual(Photos.PHAssetPlaybackStyleVideoLooping, 5)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos
import Quartz

PHAssetImageProgressHandler = b"vd@o^Z@"
PHAssetVideoProgressHandler = b"vd@o^Z@"


class TestPHImageManager(TestCase):
    @min_os_level("10.13")
    def testConstants(self):
        self.assertEqual(Photos.PHImageRequestOptionsVersionCurrent, 0)
        self.assertEqual(Photos.PHImageRequestOptionsVersionUnadjusted, 1)
        self.assertEqual(Photos.PHImageRequestOptionsVersionOriginal, 2)

        self.assertEqual(Photos.PHImageRequestOptionsDeliveryModeOpportunistic, 0)
        self.assertEqual(Photos.PHImageRequestOptionsDeliveryModeHighQualityFormat, 1)
        self.assertEqual(Photos.PHImageRequestOptionsDeliveryModeFastFormat, 2)

        self.assertEqual(Photos.PHImageRequestOptionsResizeModeNone, 0)
        self.assertEqual(Photos.PHImageRequestOptionsResizeModeFast, 1)
        self.assertEqual(Photos.PHImageRequestOptionsResizeModeExact, 2)

        self.assertEqual(Photos.PHInvalidImageRequestID, 0)

        self.assertIsInstance(Photos.PHImageManagerMaximumSize, Quartz.CGSize)

        self.assertIsInstance(Photos.PHImageResultIsInCloudKey, str)
        self.assertIsInstance(Photos.PHImageResultIsDegradedKey, str)
        self.assertIsInstance(Photos.PHImageResultRequestIDKey, str)
        self.assertIsInstance(Photos.PHImageCancelledKey, str)
        self.assertIsInstance(Photos.PHImageErrorKey, str)

        self.assertEqual(Photos.PHVideoRequestOptionsDeliveryModeAutomatic, 0)
        self.assertEqual(Photos.PHVideoRequestOptionsDeliveryModeHighQualityFormat, 1)
        self.assertEqual(Photos.PHVideoRequestOptionsDeliveryModeMediumQualityFormat, 2)
        self.assertEqual(Photos.PHVideoRequestOptionsDeliveryModeFastFormat, 3)

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertResultIsBOOL(Photos.PHImageRequestOptions.isNetworkAccessAllowed)
        self.assertArgIsBOOL(Photos.PHImageRequestOptions.setNetworkAccessAllowed_, 0)

        self.assertResultIsBOOL(Photos.PHImageRequestOptions.isSynchronous)
        self.assertArgIsBOOL(Photos.PHImageRequestOptions.setSynchronous_, 0)

        self.assertResultIsBlock(
            Photos.PHImageRequestOptions.progressHandler, PHAssetImageProgressHandler
        )
        self.assertArgIsBlock(
            Photos.PHImageRequestOptions.setProgressHandler_,
            0,
            PHAssetImageProgressHandler,
        )

        self.assertArgIsBlock(
            Photos.PHImageManager.requestImageForAsset_targetSize_contentMode_options_resultHandler_,
            4,
            b"v@@",
        )
        self.assertArgIsBlock(
            Photos.PHImageManager.requestImageDataForAsset_options_resultHandler_,
            2,
            b"v@@I@",
        )

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(Photos.PHLivePhotoRequestOptions.isNetworkAccessAllowed)
        self.assertArgIsBOOL(
            Photos.PHLivePhotoRequestOptions.setNetworkAccessAllowed_, 0
        )

        self.assertResultIsBlock(
            Photos.PHLivePhotoRequestOptions.progressHandler,
            PHAssetImageProgressHandler,
        )
        self.assertArgIsBlock(
            Photos.PHLivePhotoRequestOptions.setProgressHandler_,
            0,
            PHAssetImageProgressHandler,
        )

        self.assertResultIsBOOL(Photos.PHVideoRequestOptions.isNetworkAccessAllowed)
        self.assertArgIsBOOL(Photos.PHVideoRequestOptions.setNetworkAccessAllowed_, 0)

        self.assertResultIsBlock(
            Photos.PHVideoRequestOptions.progressHandler, PHAssetVideoProgressHandler
        )
        self.assertArgIsBlock(
            Photos.PHVideoRequestOptions.setProgressHandler_,
            0,
            PHAssetVideoProgressHandler,
        )

        self.assertArgIsBlock(
            Photos.PHImageManager.requestImageDataAndOrientationForAsset_options_resultHandler_,
            2,
            b"v@@I@",
        )
        self.assertArgIsBlock(
            Photos.PHImageManager.requestLivePhotoForAsset_targetSize_contentMode_options_resultHandler_,
            4,
            b"v@@",
        )
        self.assertArgIsBlock(
            Photos.PHImageManager.requestPlayerItemForVideo_options_resultHandler_,
            2,
            b"v@@",
        )
        self.assertArgIsBlock(
            Photos.PHImageManager.requestExportSessionForVideo_options_exportPreset_resultHandler_,
            3,
            b"v@@",
        )
        self.assertArgIsBlock(
            Photos.PHImageManager.requestAVAssetForVideo_options_resultHandler_,
            2,
            b"v@@@",
        )



# This file is generated by objective.metadata
#
# Last update: Sun Jun 28 11:45:05 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$PHContentEditingInputCancelledKey$PHContentEditingInputErrorKey$PHContentEditingInputResultIsInCloudKey$PHImageCancelledKey$PHImageErrorKey$PHImageManagerMaximumSize@{CGSize=dd}$PHImageResultIsDegradedKey$PHImageResultIsInCloudKey$PHImageResultRequestIDKey$PHLivePhotoEditingErrorDomain$PHLivePhotoInfoCancelledKey$PHLivePhotoInfoErrorKey$PHLivePhotoInfoIsDegradedKey$PHLivePhotoShouldRenderAtPlaybackTime$PHLocalIdentifierNotFound$PHPhotosErrorDomain$"""
enums = """$PHAccessLevelAddOnly@1$PHAccessLevelReadWrite@2$PHAssetBurstSelectionTypeAutoPick@1$PHAssetBurstSelectionTypeNone@0$PHAssetBurstSelectionTypeUserPick@2$PHAssetCollectionSubtypeAlbumCloudShared@101$PHAssetCollectionSubtypeAlbumImported@6$PHAssetCollectionSubtypeAlbumMyPhotoStream@100$PHAssetCollectionSubtypeAlbumRegular@2$PHAssetCollectionSubtypeAlbumSyncedAlbum@5$PHAssetCollectionSubtypeAlbumSyncedEvent@3$PHAssetCollectionSubtypeAlbumSyncedFaces@4$PHAssetCollectionSubtypeAny@9223372036854775807$PHAssetCollectionSubtypeSmartAlbumAllHidden@205$PHAssetCollectionSubtypeSmartAlbumAnimated@214$PHAssetCollectionSubtypeSmartAlbumBursts@207$PHAssetCollectionSubtypeSmartAlbumDepthEffect@212$PHAssetCollectionSubtypeSmartAlbumFavorites@203$PHAssetCollectionSubtypeSmartAlbumGeneric@200$PHAssetCollectionSubtypeSmartAlbumLivePhotos@213$PHAssetCollectionSubtypeSmartAlbumLongExposures@215$PHAssetCollectionSubtypeSmartAlbumPanoramas@201$PHAssetCollectionSubtypeSmartAlbumRecentlyAdded@206$PHAssetCollectionSubtypeSmartAlbumScreenshots@211$PHAssetCollectionSubtypeSmartAlbumSelfPortraits@210$PHAssetCollectionSubtypeSmartAlbumSlomoVideos@208$PHAssetCollectionSubtypeSmartAlbumTimelapses@204$PHAssetCollectionSubtypeSmartAlbumUnableToUpload@216$PHAssetCollectionSubtypeSmartAlbumUserLibrary@209$PHAssetCollectionSubtypeSmartAlbumVideos@202$PHAssetCollectionTypeAlbum@1$PHAssetCollectionTypeMoment@3$PHAssetCollectionTypeSmartAlbum@2$PHAssetEditOperationContent@2$PHAssetEditOperationDelete@1$PHAssetEditOperationProperties@3$PHAssetMediaSubtypeNone@0$PHAssetMediaSubtypePhotoDepthEffect@16$PHAssetMediaSubtypePhotoHDR@2$PHAssetMediaSubtypePhotoLive@8$PHAssetMediaSubtypePhotoPanorama@1$PHAssetMediaSubtypePhotoScreenshot@4$PHAssetMediaSubtypeVideoHighFrameRate@131072$PHAssetMediaSubtypeVideoStreamed@65536$PHAssetMediaSubtypeVideoTimelapse@262144$PHAssetMediaTypeAudio@3$PHAssetMediaTypeImage@1$PHAssetMediaTypeUnknown@0$PHAssetMediaTypeVideo@2$PHAssetPlaybackStyleImage@1$PHAssetPlaybackStyleImageAnimated@2$PHAssetPlaybackStyleLivePhoto@3$PHAssetPlaybackStyleUnsupported@0$PHAssetPlaybackStyleVideo@4$PHAssetPlaybackStyleVideoLooping@5$PHAssetResourceTypeAdjustmentBasePairedVideo@11$PHAssetResourceTypeAdjustmentBasePhoto@8$PHAssetResourceTypeAdjustmentBaseVideo@12$PHAssetResourceTypeAdjustmentData@7$PHAssetResourceTypeAlternatePhoto@4$PHAssetResourceTypeAudio@3$PHAssetResourceTypeFullSizePairedVideo@10$PHAssetResourceTypeFullSizePhoto@5$PHAssetResourceTypeFullSizeVideo@6$PHAssetResourceTypePairedVideo@9$PHAssetResourceTypePhoto@1$PHAssetResourceTypeVideo@2$PHAssetSourceTypeCloudShared@2$PHAssetSourceTypeNone@0$PHAssetSourceTypeUserLibrary@1$PHAssetSourceTypeiTunesSynced@4$PHAuthorizationStatusAuthorized@3$PHAuthorizationStatusDenied@2$PHAuthorizationStatusLimited@4$PHAuthorizationStatusNotDetermined@0$PHAuthorizationStatusRestricted@1$PHCollectionEditOperationAddContent@3$PHCollectionEditOperationCreateContent@4$PHCollectionEditOperationDelete@6$PHCollectionEditOperationDeleteContent@1$PHCollectionEditOperationRearrangeContent@5$PHCollectionEditOperationRemoveContent@2$PHCollectionEditOperationRename@7$PHCollectionListSubtypeAny@9223372036854775807$PHCollectionListSubtypeMomentListCluster@1$PHCollectionListSubtypeMomentListYear@2$PHCollectionListSubtypeRegularFolder@100$PHCollectionListSubtypeSmartFolderEvents@200$PHCollectionListSubtypeSmartFolderFaces@201$PHCollectionListTypeFolder@2$PHCollectionListTypeMomentList@1$PHCollectionListTypeSmartFolder@3$PHImageContentModeAspectFill@1$PHImageContentModeAspectFit@0$PHImageContentModeDefault@0$PHImageRequestOptionsDeliveryModeFastFormat@2$PHImageRequestOptionsDeliveryModeHighQualityFormat@1$PHImageRequestOptionsDeliveryModeOpportunistic@0$PHImageRequestOptionsResizeModeExact@2$PHImageRequestOptionsResizeModeFast@1$PHImageRequestOptionsResizeModeNone@0$PHImageRequestOptionsVersionCurrent@0$PHImageRequestOptionsVersionOriginal@2$PHImageRequestOptionsVersionUnadjusted@1$PHInvalidAssetResourceDataRequestID@0$PHInvalidImageRequestID@0$PHLivePhotoEditingErrorCodeAborted@1$PHLivePhotoEditingErrorCodeUnknown@0$PHLivePhotoFrameTypePhoto@0$PHLivePhotoFrameTypeVideo@1$PHLivePhotoRequestIDInvalid@0$PHPhotosErrorInvalid@-1$PHPhotosErrorLibraryVolumeOffline@3114$PHPhotosErrorNetworkAccessRequired@3164$PHPhotosErrorRelinquishingLibraryBundleToWriter@3142$PHPhotosErrorSwitchingSystemPhotoLibrary@3143$PHPhotosErrorUserCancelled@3072$PHVideoRequestOptionsDeliveryModeAutomatic@0$PHVideoRequestOptionsDeliveryModeFastFormat@3$PHVideoRequestOptionsDeliveryModeHighQualityFormat@1$PHVideoRequestOptionsDeliveryModeMediumQualityFormat@2$PHVideoRequestOptionsVersionCurrent@0$PHVideoRequestOptionsVersionOriginal@1$"""
misc.update({})
aliases = {
    "PHCollectionListSubtypeAny": "NSIntegerMax",
    "PHAssetCollectionSubtypeAny": "NSIntegerMax",
    "PHImageContentModeDefault": "PHImageContentModeAspectFit",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"NSObject", b"image", {"required": True, "retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"photoLibraryDidBecomeUnavailable:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"photoLibraryDidChange:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"renderScale",
        {"required": True, "retval": {"type": sel32or64(b"f", b"d")}},
    )
    r(b"NSObject", b"time", {"required": True, "retval": {"type": "{_CMTime=qiIq}"}})
    r(
        b"NSObject",
        b"type",
        {"required": True, "retval": {"type": sel32or64(b"i", b"q")}},
    )
    r(b"PHAsset", b"canPerformEditOperation:", {"retval": {"type": "Z"}})
    r(b"PHAsset", b"isFavorite", {"retval": {"type": "Z"}})
    r(b"PHAsset", b"isHidden", {"retval": {"type": "Z"}})
    r(b"PHAsset", b"isSyncFailureHidden", {"retval": {"type": "Z"}})
    r(b"PHAsset", b"representsBurst", {"retval": {"type": "Z"}})
    r(
        b"PHAsset",
        b"requestContentEditingInputWithOptions:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"PHAssetChangeRequest", b"isFavorite", {"retval": {"type": b"Z"}})
    r(b"PHAssetChangeRequest", b"isHidden", {"retval": {"type": b"Z"}})
    r(b"PHAssetChangeRequest", b"setFavorite:", {"arguments": {2: {"type": b"Z"}}})
    r(b"PHAssetChangeRequest", b"setHidden:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"PHAssetCreationRequest",
        b"supportsAssetResourceTypes:",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"PHAssetResourceCreationOptions",
        b"setShouldMoveFile:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"PHAssetResourceCreationOptions", b"shouldMoveFile", {"retval": {"type": b"Z"}})
    r(
        b"PHAssetResourceManager",
        b"requestDataForAssetResource:options:dataReceivedHandler:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                },
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                },
            }
        },
    )
    r(
        b"PHAssetResourceManager",
        b"writeDataForAssetResource:toFile:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"PHAssetResourceRequestOptions",
        b"isNetworkAccessAllowed",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"PHAssetResourceRequestOptions",
        b"setNetworkAccessAllowed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"PHAssetResourceRequestOptions",
        b"setProgressHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"PHCachingImageManager",
        b"allowsCachingHighQualityImages",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"PHCachingImageManager",
        b"setAllowsCachingHighQualityImages:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"PHCollection", b"canContainAssets", {"retval": {"type": b"Z"}})
    r(b"PHCollection", b"canContainCollections", {"retval": {"type": b"Z"}})
    r(b"PHCollection", b"canPerformEditOperation:", {"retval": {"type": b"Z"}})
    r(
        b"PHContentEditingInputRequestOptions",
        b"isNetworkAccessAllowed",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"PHContentEditingInputRequestOptions",
        b"progressHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"d"},
                        2: {"type": b"o^Z"},
                    },
                }
            }
        },
    )
    r(
        b"PHContentEditingInputRequestOptions",
        b"setCanHandleAdjustmentData:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"PHContentEditingInputRequestOptions",
        b"setNetworkAccessAllowed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"PHContentEditingInputRequestOptions",
        b"setProgressHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"d"},
                            2: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(b"PHFetchOptions", b"includeAllBurstAssets", {"retval": {"type": b"Z"}})
    r(b"PHFetchOptions", b"includeHiddenAssets", {"retval": {"type": "Z"}})
    r(
        b"PHFetchOptions",
        b"setIncludeAllBurstAssets:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"PHFetchOptions", b"setIncludeHiddenAssets:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"PHFetchOptions",
        b"setWantsIncrementalChangeDetails:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"PHFetchOptions", b"wantsIncrementalChangeDetails", {"retval": {"type": "Z"}})
    r(b"PHFetchResult", b"containsObject:", {"retval": {"type": "Z"}})
    r(
        b"PHFetchResult",
        b"enumerateObjectsAtIndexes:options:usingBlock:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"I", b"Q")},
                            3: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHFetchResult",
        b"enumerateObjectsUsingBlock:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"I", b"Q")},
                            3: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHFetchResult",
        b"enumerateObjectsWithOptions:usingBlock:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": sel32or64(b"I", b"Q")},
                            3: {"type": b"o^Z"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHFetchResultChangeDetails",
        b"enumerateMovesWithBlock:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Q"},
                            2: {"type": b"Q"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHFetchResultChangeDetails",
        b"hasIncrementalChanges",
        {"retval": {"type": "Z"}},
    )
    r(b"PHFetchResultChangeDetails", b"hasMoves", {"retval": {"type": "Z"}})
    r(
        b"PHImageManager",
        b"requestAVAssetForVideo:options:resultHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestExportSessionForVideo:options:exportPreset:resultHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestImageDataAndOrientationForAsset:options:resultHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"I"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestImageDataForAsset:options:resultHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"I"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestImageForAsset:targetSize:contentMode:options:resultHandler:",
        {
            "arguments": {
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestLivePhotoForAsset:targetSize:contentMode:options:resultHandler:",
        {
            "arguments": {
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHImageManager",
        b"requestPlayerItemForVideo:options:resultHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"PHImageRequestOptions", b"isNetworkAccessAllowed", {"retval": {"type": "Z"}})
    r(b"PHImageRequestOptions", b"isSynchronous", {"retval": {"type": "Z"}})
    r(
        b"PHImageRequestOptions",
        b"progressHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"d"},
                        2: {"type": b"@"},
                        3: {"type": b"o^Z"},
                        4: {"type": b"@"},
                    },
                }
            }
        },
    )
    r(
        b"PHImageRequestOptions",
        b"setNetworkAccessAllowed:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"PHImageRequestOptions",
        b"setProgressHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"d"},
                            2: {"type": b"@"},
                            3: {"type": b"o^Z"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"PHImageRequestOptions", b"setSynchronous:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"PHLivePhoto",
        b"requestLivePhotoWithResourceFileURLs:placeholderImage:targetSize:contentMode:resultHandler:",
        {
            "arguments": {
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHLivePhotoEditingContext",
        b"duration",
        {"retval": {"type": b"{_CMTime=qiIq}"}},
    )
    r(
        b"PHLivePhotoEditingContext",
        b"frameProcessor",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"@"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": b"o^@"},
                    },
                }
            }
        },
    )
    r(
        b"PHLivePhotoEditingContext",
        b"photoTime",
        {"retval": {"type": b"{_CMTime=qiIq}"}},
    )
    r(
        b"PHLivePhotoEditingContext",
        b"prepareLivePhotoForPlaybackWithTargetSize:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHLivePhotoEditingContext",
        b"saveLivePhotoToOutput:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHLivePhotoEditingContext",
        b"setFrameProcessor:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"o^@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"PHLivePhotoRequestOptions",
        b"isNetworkAccessAllowed",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"PHLivePhotoRequestOptions",
        b"progressHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"d"},
                        2: {"type": b"@"},
                        3: {"type": b"o^Z"},
                        4: {"type": b"@"},
                    },
                }
            }
        },
    )
    r(
        b"PHLivePhotoRequestOptions",
        b"setNetworkAccessAllowed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"PHLivePhotoRequestOptions",
        b"setProgressHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"d"},
                            2: {"type": b"@"},
                            3: {"type": b"o^Z"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"PHObjectChangeDetails", b"assetContentChanged", {"retval": {"type": "Z"}})
    r(b"PHObjectChangeDetails", b"objectWasDeleted", {"retval": {"type": "Z"}})
    r(
        b"PHPhotoLibrary",
        b"performChanges:completionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                },
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"PHPhotoLibrary",
        b"performChangesAndWait:error:",
        {
            "retval": {"type": "Z"},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                },
                3: {"type_modifier": b"o"},
            },
        },
    )
    r(
        b"PHPhotoLibrary",
        b"requestAuthorization:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"q"}},
                    }
                }
            }
        },
    )
    r(
        b"PHPhotoLibrary",
        b"requestAuthorizationForAccessLevel:handler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"q"}},
                    }
                }
            }
        },
    )
    r(b"PHProject", b"hasProjectPreview", {"retval": {"type": "Z"}})
    r(b"PHVideoRequestOptions", b"isNetworkAccessAllowed", {"retval": {"type": b"Z"}})
    r(
        b"PHVideoRequestOptions",
        b"progressHandler",
        {
            "comment": "XXX",
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"d"},
                        2: {"type": b"@"},
                        3: {"type": b"o^Z"},
                        4: {"type": b"@"},
                    },
                }
            },
        },
    )
    r(
        b"PHVideoRequestOptions",
        b"setNetworkAccessAllowed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"PHVideoRequestOptions",
        b"setProgressHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"d"},
                            2: {"type": b"@"},
                            3: {"type": b"o^Z"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"null",
        b"requestContentEditingInputWithOptions:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase
import Photos


class TestPHError(TestCase):
    def test_constants(self):
        self.assertEqual(Photos.PHPhotosErrorInvalid, -1)
        self.assertEqual(Photos.PHPhotosErrorUserCancelled, 3072)
        self.assertEqual(Photos.PHPhotosErrorLibraryVolumeOffline, 3114)
        self.assertEqual(Photos.PHPhotosErrorRelinquishingLibraryBundleToWriter, 3142)
        self.assertEqual(Photos.PHPhotosErrorSwitchingSystemPhotoLibrary, 3143)
        self.assertEqual(Photos.PHPhotosErrorNetworkAccessRequired, 3164)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import objc
import Photos


class TestPHPhotoLibrary(TestCase):
    def testConstants(self):
        self.assertEqual(Photos.PHAuthorizationStatusNotDetermined, 0)
        self.assertEqual(Photos.PHAuthorizationStatusRestricted, 1)
        self.assertEqual(Photos.PHAuthorizationStatusDenied, 2)
        self.assertEqual(Photos.PHAuthorizationStatusAuthorized, 3)

        self.assertEqual(Photos.PHAccessLevelAddOnly, 1)
        self.assertEqual(Photos.PHAccessLevelReadWrite, 2)

    @min_sdk_level("10.13")
    def testProtocols(self):
        objc.protocolNamed("PHPhotoLibraryChangeObserver")

    @min_sdk_level("10.15")
    def testProtocols10_15(self):
        objc.protocolNamed("PHPhotoLibraryAvailabilityObserver")

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBlock(
            Photos.PHPhotoLibrary.requestAuthorization_, 0, b"v" + objc._C_NSInteger
        )
        self.assertArgIsBlock(
            Photos.PHPhotoLibrary.performChanges_completionHandler_, 1, b"vZ@"
        )
        self.assertArgIsOut(Photos.PHPhotoLibrary.performChangesAndWait_error_, 1)
        self.assertResultIsBOOL(Photos.PHPhotoLibrary.performChangesAndWait_error_)

    @min_os_level("10.16")
    def testMethods10_16(self):
        self.assertArgIsBlock(
            Photos.PHPhotoLibrary.requestAuthorizationForAccessLevel_handler_,
            1,
            b"v" + objc._C_NSInteger,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Photos

PHAssetResourceProgressHandler = b"vd"


class TestPHAssetResourceManager(TestCase):
    @min_os_level("10.15")
    def testMethods(self):
        self.assertResultIsBOOL(
            Photos.PHContentEditingInputRequestOptions.isNetworkAccessAllowed
        )
        self.assertArgIsBOOL(
            Photos.PHContentEditingInputRequestOptions.setNetworkAccessAllowed_, 0
        )

        self.assertArgIsBlock(
            Photos.PHAssetResourceManager.requestDataForAssetResource_options_dataReceivedHandler_completionHandler_,
            2,
            b"v@",
        )
        self.assertArgIsBlock(
            Photos.PHAssetResourceManager.requestDataForAssetResource_options_dataReceivedHandler_completionHandler_,
            3,
            b"v@",
        )

        self.assertArgIsBlock(
            Photos.PHAssetResourceManager.writeDataForAssetResource_toFile_options_completionHandler_,
            3,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHFetchOptions(TestCase):
    @min_os_level("10.13")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHFetchOptions.includeHiddenAssets)
        self.assertArgIsBOOL(Photos.PHFetchOptions.setIncludeHiddenAssets_, 0)
        self.assertResultIsBOOL(Photos.PHFetchOptions.wantsIncrementalChangeDetails)
        self.assertArgIsBOOL(Photos.PHFetchOptions.setWantsIncrementalChangeDetails_, 0)

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(Photos.PHFetchOptions.includeAllBurstAssets)
        self.assertArgIsBOOL(Photos.PHFetchOptions.setIncludeAllBurstAssets_, 0)



"""
Python mapping for the Photos framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from Photos import _metadata
from Photos import _Photos

sys.modules["Photos"] = mod = objc.ObjCLazyModule(
    "Photos",
    "com.apple.photos",
    objc.pathForFramework("/System/Library/Frameworks/Photos.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_Photos, Foundation),
)


del sys.modules["Photos._metadata"]



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHCollection(TestCase):
    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(Photos.PHCollection.canContainAssets)
        self.assertResultIsBOOL(Photos.PHCollection.canContainCollections)
        self.assertResultIsBOOL(Photos.PHCollection.canPerformEditOperation_)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import objc
import Photos


class TestPHLivePhotoEditingContextHelper(Photos.NSObject):
    def time(self):
        return 1

    def type(self):  # noqa: A003
        return 1

    def renderScale(self):
        return 1


class TestPHLivePhotoEditingContext(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        PHLivePhotoFrameProcessingBlock = b"@@o^@"

        self.assertResultIsBlock(
            Photos.PHLivePhotoEditingContext.frameProcessor,
            PHLivePhotoFrameProcessingBlock,
        )
        self.assertArgIsBlock(
            Photos.PHLivePhotoEditingContext.setFrameProcessor_,
            0,
            PHLivePhotoFrameProcessingBlock,
        )

        self.assertArgIsBlock(
            Photos.PHLivePhotoEditingContext.prepareLivePhotoForPlaybackWithTargetSize_options_completionHandler_,
            2,
            b"vZ@",
        )
        self.assertArgIsBlock(
            Photos.PHLivePhotoEditingContext.saveLivePhotoToOutput_options_completionHandler_,
            2,
            b"vZ@",
        )

        self.assertResultHasType(
            TestPHLivePhotoEditingContextHelper.time, b"{_CMTime=qiIq}"
        )  # Photos.CMTime.__typestr__
        self.assertResultHasType(
            TestPHLivePhotoEditingContextHelper.type, objc._C_NSInteger
        )
        self.assertResultHasType(
            TestPHLivePhotoEditingContextHelper.renderScale, objc._C_CGFloat
        )

    @min_os_level("10.12")
    def testContants(self):
        self.assertEqual(Photos.PHLivePhotoFrameTypePhoto, 0)
        self.assertEqual(Photos.PHLivePhotoFrameTypeVideo, 1)

        self.assertIsInstance(Photos.PHLivePhotoEditingErrorDomain, str)
        self.assertIsInstance(Photos.PHLivePhotoShouldRenderAtPlaybackTime, str)

        self.assertEqual(Photos.PHLivePhotoEditingErrorCodeUnknown, 0)
        self.assertEqual(Photos.PHLivePhotoEditingErrorCodeAborted, 1)

    @min_sdk_level("10.12")
    def testProtocols(self):
        objc.protocolNamed("PHLivePhotoFrame")



from PyObjCTools.TestSupport import TestCase, min_os_level
import Photos


class TestPHAssetResourceCreationOptions(TestCase):
    @min_os_level("10.15")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHAssetResourceCreationOptions.shouldMoveFile)
        self.assertArgIsBOOL(
            Photos.PHAssetResourceCreationOptions.setShouldMoveFile_, 0
        )

        self.assertResultIsBOOL(
            Photos.PHAssetCreationRequest.supportsAssetResourceTypes_
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import Photos


class TestPHAdjustmentData(TestCase):
    @min_os_level("10.11")
    def testClasses(self):
        self.assertIsInstance(Photos.PHAdjustmentData, objc.objc_class)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import Photos


class TestPHFetchResult(TestCase):
    @min_os_level("10.13")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHFetchResult.containsObject_)
        self.assertArgIsBlock(
            Photos.PHFetchResult.enumerateObjectsUsingBlock_,
            0,
            b"v@" + objc._C_NSUInteger + b"o^Z",
        )
        self.assertArgIsBlock(
            Photos.PHFetchResult.enumerateObjectsWithOptions_usingBlock_,
            1,
            b"v@" + objc._C_NSUInteger + b"o^Z",
        )
        self.assertArgIsBlock(
            Photos.PHFetchResult.enumerateObjectsAtIndexes_options_usingBlock_,
            2,
            b"v@" + objc._C_NSUInteger + b"o^Z",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Photos


class TestPHAssetChangeRequest(TestCase):
    @min_os_level("10.15")
    def testMethods(self):
        self.assertResultIsBOOL(Photos.PHAssetChangeRequest.isFavorite)
        self.assertArgIsBOOL(Photos.PHAssetChangeRequest.setFavorite_, 0)

        self.assertResultIsBOOL(Photos.PHAssetChangeRequest.isHidden)
        self.assertArgIsBOOL(Photos.PHAssetChangeRequest.setHidden_, 0)

        self.assertResultIsBOOL(
            Photos.PHContentEditingInputRequestOptions.isNetworkAccessAllowed
        )
        self.assertArgIsBOOL(
            Photos.PHContentEditingInputRequestOptions.setNetworkAccessAllowed_, 0
        )

        self.assertResultIsBlock(
            Photos.PHContentEditingInputRequestOptions.progressHandler, b"vdo^Z"
        )
        self.assertArgIsBlock(
            Photos.PHContentEditingInputRequestOptions.setProgressHandler_, 0, b"vdo^Z"
        )

        self.assertArgIsBlock(
            Photos.PHAsset.requestContentEditingInputWithOptions_completionHandler_,
            1,
            b"v@@",
        )

    @min_os_level("10.15")
    def test_constants(self):
        self.assertIsInstance(Photos.PHContentEditingInputResultIsInCloudKey, str)
        self.assertIsInstance(Photos.PHContentEditingInputCancelledKey, str)
        self.assertIsInstance(Photos.PHContentEditingInputErrorKey, str)
